@@ -117,7 +117,7 @@ search.paths.ms <- function(obj,
         #------------------------------------------------------#
         # Add the parameters with the largest MI
         #------------------------------------------------------#
-        if (!all(is.na(mi_list))){
+        if (!all(is.na(unlist(mi_list)))){
           if (ms_allow)
           add_p     <- highest.mi(mi_list      = mi_list,
                                   indices      = indices,
